package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````_!<``#0````XP0```````#0`(``)
M`"@`&P`:``8````T````-````#0````@`0``(`$```0````$`````P```%0!
M``!4`0``5`$``!,````3````!`````$````!````````````````````-*\`
M`#2O```%`````!````$```"HO0``J,T``*C-``!H`@``K!(```8`````$```
M`@```+"]``"PS0``L,T``"`!```@`0``!@````0````$````:`$``&@!``!H
M`0``1````$0````$````!````%#E=&2TH```M*```+2@``#T````]`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DJ+T`
M`*C-``"HS0``6`(``%@"```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,@``
M!````!`````!````1TY5```````#`````@`````````$````%`````,```!'
M3E4`)#"?':;-V4PZZ:BK**,L7=-%)ZP1````2P````@````(`````!`0!"5`
M!(`H`0`!H(8`@(`!```+*`0).*`218H$"`@`````2P```$\```!3````5```
M`%H```!;````7````%X```!?`````````&$```!C````9````&4`````````
M`````.K3[PYNQ=\?SMY'+6M_FGPNQ9NVU&34?"#_Y`ZYC?$.V7%8'.)'Q@&R
M`8MOK$OCP,+E/RRZXY)\^Z%L8&L)0]9GK\QF0D75[(D'<-,-%.*>,F+;[=O-
MXYX,.I<+6>CM['^IG)OAIP(*H^#[20`````````````````````8`@``````
M```````2````C`(`````````````$@```'<"`````````````!(````,`0``
M```````````2````DP``````````````$@````$!`````````````!$```#*
M`@`````````````2````DP$`````````````$@```+4"`````````````!(`
M```B`0`````````````2````$0``````````````(````'T"````````````
M`!(```#K`@`````````````2````&0,`````````````$@```$@"````````
M`````!(```#W`0`````````````2````4P$`````````````$@```+0`````
M`````````!(```!#`0`````````````2````-0$`````````````$@```%T#
M`````````````!(````,`P`````````````2````!`(`````````````$@``
M`/\!`````````````!(````@```````````````@````L0$`````````````
M$@```!$!`````````````!(```#8`@`````````````2````3P,`````````
M````$@```#P``````````````"````#C`@`````````````2````5@``````
M````````$@```(,!`````````````!(```!S```````````````2````\```
M````````````$@```(0``````````````!(````@`P`````````````2````
M]0(`````````````$0```,,"`````````````!(```"A`@`````````````2
M````<`(`````````````$@```#T$`````````````!(```#4````````````
M```2````_`(`````````````$@```'$#`````````````!$```!U`0``````
M```````2````9P(`````````````$@```"D"`````````````!(```!G`0``
M```````````2````J`(`````````````$@```*H!`````````````!(````6
M`0`````````````2````>0,`````````````$@```*\"`````````````!(`
M``!P`P`````````````A````F@(`````````````$@````,#````````````
M`!(```!'`P`````````````2````GP``````````````$@```)X!````````
M`````!(````Y`P`````````````2````;P,`````````````$0```(4"````
M`````````!(```!?`@`````````````2````\`$`````````````$@```.,`
M`````````````!$```"\`0`````````````1````7`$`````````````$@``
M`&0``````````````!(```"3`@`````````````2````5@,`````````````
M$@```"H#`````````````"(```!:`@`````````````2````P@``````````
M````$@```-@#``!D80```````!(`#P!&!```,&```&\````2``X`=P0``.!/
M``"Q#```$@`.`&H#``#`%0``/`(``!(`#@"P`P``($D```4````2``X`Y0,`
M`*!<``"&`P``$@`.`)8$```P20``)0(``!(`#@!A!```O!$````````2``L`
MGP,``!#0````````$``8`,$#``!@2P``*@```!(`#@#[`P``4$X``'8````2
M``X`.0(``'QA```$````$0`0`%\$``#`1P``.P```!(`#@"K`P``5.``````
M```0`!@`A`0``!!/``#'````$@`.`%($````T````````!``%P`?!```D$L`
M`.<````2``X`F`,``!#0````````$``7`*,$```,T```!````!$`%P#.`P``
M0&$```(````2``X`6`0``/P7````````$@`.`&<$``#@8```70```!(`#@!4
M!````-`````````@`!<`W@,``'AA```$````$0`0`"L$``#03@``-````!(`
M#@`)!```8$@``+D````2``X`K00``(!,``#$`0``$@`.``!L:6)P97)L+G-O
M+C4N,C8`7U]G;6]N7W-T87)T7U\`7TE435]D97)E9VES=&5R5$U#;&]N951A
M8FQE`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!0
M97)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T
M`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI
M9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD
M=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R
M;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R
M;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C
M=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E
M<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI
M8F1L+G-O+C(`;&EB;2YS;RXV`&QI8G!T:')E860N<V\N,`!O<&5N-C0`;'-E
M96LV-`!R96%D`'!T:')E861?9V5T<W!E8VEF:6,`7U]E<G)N;U]L;V-A=&EO
M;@!C;&]S90!L:6)C+G-O+C8`7TE/7W-T9&EN7W5S960`7U]R96=I<W1E<E]A
M=&9O<FL`97AI=`!S=')N8VUP`&-L;W-E9&ER`'5N;&EN:P!M:V1I<@!R96%L
M;&]C`&UE;6-H<@!G971P:60`<W1R9'5P`'-T<G1O:P!S=')L96X`<W1R<W1R
M`')M9&ER`%]?9G!R:6YT9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L
M>'-T870V-`!O<&5N9&ER`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L
M:6YK`%]?;65M8W!Y7V-H:P!S=')C:'(`<F5A9&1I<C8T`%]?8WAA7V9I;F%L
M:7IE`%]?<W!R:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB
M8U]S=&%R=%]M86EN`%]?96YV:7)O;@!?7W-T86-K7V-H:U]F86EL`&QI8F-R
M>7!T+G-O+C$`7V5D871A`%]?8G-S7W-T87)T`%]E;F0`<&%R7V-U<G)E;G1?
M97AE8P!P87)?8F%S96YA;64`7U]L:6)C7V-S=5]F:6YI`%]F<%]H=P!84U])
M;G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E
M>&5C7W!R;V,`<&%R7V1I<FYA;64`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U
M:60`<&%R7V-L96%N=7``7U]D871A7W-T87)T`'AS7VEN:70`7U]L:6)C7V-S
M=5]I;FET`'!A<E]M:W1M<&1I<@!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN
M9'!R;V<`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!'3$E"0U\R+C$N,P!'3$E"
M0U\R+C0`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXR`$=,24)#7S(N,RXT`$=,24)#
M7S(N,`````(``P`#``````````0````$```````#``4``P`&``<`````````
M```#``0``@`"```````#``4``P````,```````````````4``P`#``,``P`#
M`````P`#`````P`"`````P`#````"``#``,``P`#``,```````0``P`#``,`
M!P````````````,``P`)``,````!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``8`+P(``!````!P````
M<Q]I"0``"0"Z!```$````!1I:0T```@`Q@0``!````!R&6D)```&`-`$```0
M````$FEI#0``!0#<!```$````'09:0D```0`Y@0``!`````0:6D-```#`/($
M`````````0`"`.`!```0`````````!)I:0T```<`W`0``!`````0:6D-```"
M`/($````````J,T```@```"LS0``"````/S/```(````!-````@````,T```
M"````,S/```&!@``T,\```8*``#4SP``!@L``-C/```&&0``W,\```8>``#@
MSP``!B$``.3/```&(@``Z,\```8F``#LSP``!BT``/#/```&0@``],\```9#
M``#XSP``!D@``-S.```'`0``X,X```<"``#DS@``!P,``.C.```'!```[,X`
M``<%``#PS@``!P<``/3.```'"```^,X```<)``#\S@``!PP```#/```'#0``
M!,\```<.```(SP``!P\```S/```'$```$,\```<1```4SP``!Q(``!C/```'
M$P``',\```<4```@SP``!Q4``"3/```'%@``*,\```<7```LSP``!Q@``##/
M```'&@``-,\```<;```XSP``!QP``#S/```''0``0,\```<?``!$SP``!R``
M`$C/```'(P``3,\```<D``!0SP``!R4``%3/```')P``6,\```<H``!<SP``
M!RD``&#/```'*@``9,\```<K``!HSP``!RP``&S/```'+@``<,\```<O``!T
MSP``!S```'C/```',0``?,\```<R``"`SP``!S,``(3/```'-```B,\```<U
M``",SP``!S8``)#/```'.```E,\```<Y``"8SP``!SH``)S/```'.P``H,\`
M``<\``"DSP``!ST``*C/```'/P``K,\```=```"PSP``!T$``+3/```'1```
MN,\```=%``"\SP``!T8``,#/```'1P``Q,\```=)``#(SP``!TH``%.#[`CH
M>P8``('#"[T``(N#!`$``(7`=`7HU@,``(/$"%O#`/^S!````/^C"```````
M``#_HPP```!H`````.G@_____Z,0````:`@```#IT/____^C%````&@0````
MZ<#_____HQ@```!H&````.FP_____Z,<````:"````#IH/____^C(````&@H
M````Z9#_____HR0```!H,````.F`_____Z,H````:#@```#I</____^C+```
M`&A`````Z6#_____HS````!H2````.E0_____Z,T````:%````#I0/____^C
M.````&A8````Z3#_____HSP```!H8````.D@_____Z-`````:&@```#I$/__
M__^C1````&AP````Z0#_____HT@```!H>````.GP_O___Z-,````:(````#I
MX/[___^C4````&B(````Z=#^____HU0```!HD````.G`_O___Z-8````:)@`
M``#IL/[___^C7````&B@````Z:#^____HV````!HJ````.F0_O___Z-D````
M:+````#I@/[___^C:````&BX````Z7#^____HVP```!HP````.E@_O___Z-P
M````:,@```#I4/[___^C=````&C0````Z4#^____HW@```!HV````.DP_O__
M_Z-\````:.````#I(/[___^C@````&CH````Z1#^____HX0```!H\````.D`
M_O___Z.(````:/@```#I\/W___^CC````&@``0``Z>#]____HY````!H"`$`
M`.G0_?___Z.4````:!`!``#IP/W___^CF````&@8`0``Z;#]____HYP```!H
M(`$``.F@_?___Z.@````:"@!``#ID/W___^CI````&@P`0``Z8#]____HZ@`
M``!H.`$``.EP_?___Z.L````:$`!``#I8/W___^CL````&A(`0``Z5#]____
MH[0```!H4`$``.E`_?___Z.X````:%@!``#I,/W___^CO````&A@`0``Z2#]
M____H\````!H:`$``.D0_?___Z/$````:'`!``#I`/W___^CR````&AX`0``
MZ?#\____H\P```!H@`$``.G@_/___Z/0````:(@!``#IT/S___^CU````&B0
M`0``Z<#\____H]@```!HF`$``.FP_/___Z/<````:*`!``#IH/S___^CX```
M`&BH`0``Z9#\____H^0```!HL`$``.F`_/___Z/H````:+@!``#I</S___^C
M[````&C``0``Z6#\____H_````!HR`$``.E0_/___Z/T````:-`!``#I0/S_
M__^C^````&C8`0``Z3#\____HP0!``!FD/^C*`$``&:0C4PD!(/D\/]Q_%6)
MY5=64U&)S^AH`@``@</XN```@^PLBT$$B474BT$(B4709:$4````B47D,<"-
M1=!0C4744%'H6O___XN#``$``(/$#%!0_[,4`0``Z)1*``"+@R`!``"#Q!"`
M.``/A"(!``"+L_P```"#[`S_-NCB_/__@(C^`@```EK_-NC3_/__@(C^`@``
M`8L'@\00@\`%/?___S\/AU4!``"#[`S!X`)0Z(W^__^+==2+#X/$$(F#=!$`
M`,>#>!$```0```"+%H/Y`8D0C9.`E/__B5`$BY,\`0``B5`(C9.#E/__B5`,
M?A>Z`0```(UT)@"+/):)?)`,@\(!.=%U\H/L#,=$B`P`````@\$#:@!0C8,P
M>?__45#_LX`1``#H9OO__X/$((7`B<8/A*T```"#[`S_LX`1``"-?>#H6/W_
M_XV#4)/__XGZZ`LJ``"#Q!"%P'1M@^P,_[.`$0``Z/;Z___H8?S__X/$$(GP
MBTWD93,-%`````^%J0```(UE\%E;7E]=C6'\P^CK^___A<")@X`1```/A(\`
M``"#[`Q0Z$3\__^+L_P```!9_S;HIOO__X/$$,:`<04```#IJ_[__XN#?!$`
M`(7`=#V#[`Q0Z)1(``"#Q!#I>/___X/L#/^S@!$``.@.^___@\00B<;I.___
M_U!0C8,"D____[,D`0``4.@@_?__C8,%D___B?KH0RD``(7`B8-\$0``#X0Q
M____ZZ;H7DD``(/L#&H!Z)3]__\Q[5Z)X8/D\%!44N@B````@</$M@``C8-P
MDO__4(V#$)+__U!15O^S+`$``.C3^O__](L<),-FD&:09I!FD&:09I!FD(L<
M),-FD&:09I!FD&:09I#HY````('">[8``(V*0`$``(V"0`$``#G(=!V+@@@!
M``"%P'0358GE@^P44?_0@\00R<.0C70F`//#C;8`````Z*0```"!PCNV``!5
MC8I``0``C8)``0``*<B)Y5/!^`*)PX/L!,'K'P'8T?AT%(N2#`$``(72=`J#
M[`A04?_2@\00BUW\R<.)]HV\)P````!5B>53Z%?___^!P^>U``"#[`2`NU`!
M````=2>+@R@!``"%P'01@^P,_[,T`0``Z*7\__^#Q!#H-?___\:#4`$```&+
M7?S)PXGVC;PG`````%6)Y5WI5____XL4),-FD)!55XUH.%93@>P,`P``C4PD
M>(E$)%2)="0098L=%````(F<)/P"```QVXE,)`B)?"04C;0F`````(M4G0"+
M1)T$QT39!`````#'1-D,`````,=$)`0`````#\J)!"2)%-F)PL'H&,'J"('B
M`/\```G0BQ0DB<>+!"3!XAC!X`@)UR4``/\`"?B)1-D(@\,"@_L0=:6+1"0(
MC90D>`(``(D4)(G%D(UT)@"+56B+16R#Q0@S53@S13PS50@S10PS5?@S1?S'
M17P`````B<>)T(G1#ZSX'P'1"<&)37@[+"1UR(M<)%2+4PR+2QR+,XM[!(M#
M"(E4)!R+4Q2)3"0,BTLDB40D&(M#$(E4)`2+4QB)3"1<B7PD%(D$)(E4)`B+
M4R"+7"0$B50D6(GRP>8%B=&)]8MT)%@/K/D;BWPD"(E4)!`)S0-T)'B)Z(GQ
MBW0D#('!F7F"6@'(BPPD,=XC="0<,<^+3"08B70D("'/B?Z+?"0(,?X!\(E$
M)""+?"08BVPD'(L$)(M4)`3'1"0D`````(GYB?['1"0\``````^L[@+!X1Z)
MQXM$)!")S8M,)`C'1"0L``````GU`XPD@````(G6B6PD,(EL)#C'1"1$````
M`('!F7F"6B-T)!0Q[R''B70D*(G^BSPD,?Z+?"0D`?&+="0@B?V)\(GWP>`%
MB40D*(MT)"@/K.\;BVPD%`G^BWPD$(GPBS0D`<B)1"0HB?F)^`^LZ`+!X1Z+
M?"0$B<V+3"0P"<4#M"2(````$[PDC````(EL)$")\(MT)"`%F7F"6HGZBWPD
M.(/2`#'I,=LASL=$)$P`````QT0D/``````Q]XG^B=^+7"0X`<:+1"0H$=>+
M5"0LB70D,(E\)#2+?"0DB<;'1"0T``````^LT!O!Y@6+5"0LB<$)\8MT)"")
MR`-$)#")\0^L_@+!X1Z)1"0PBWPD,`GQ`YPDD````(E,)&")3"1(B=@%F7F"
M6C'-(VPD*#-L)$")Z8ML)#0!P8GXP>`%B40D((MT)"`/K.\;"?Z)\`'(,?^)
MQHM$)"B)P<'A'@^LT`*)S8M4)$"+3"1@"<4#E"28````B6PD.(EL)$")T`69
M>8):,>DC3"0PBVPD2(M4)#3'1"0D`````,=$)#0`````QT0D1``````QS8GI
M`<&)\,'@!8E$)"")\(ML)"`/K/@;B40D*`ML)"B)Z(ML)$`!R(E$)""+1"0P
MB<$/K-`"P>$>BU0D3`G!BT0D2`.$)*`````3E"2D````B4PD,(E,)$@%F7F"
M6H/2`#'-,=LA]3-L)#B)Z0'!BT0D(!'3BU0D)(E,)"B)7"0LQT0D+`````")
MP<'A!8E,)$")T8ML)$")P@^LRAN)\0G5B>@#1"0HP>$>#ZS^`HG-"?6)1"0H
MB6PD0(M<)#@#G"2H````BW0D/!.T)*P```"+3"1(B=B)\HMT)"`%F7F"6H/2
M`#'I,=N)WR'.,W0D,`'&BT0D*!'7BU0D+(ET)#B)?"0\QT0D/`````")Q@^L
MT!O!Y@6+5"0DQT0D)`````")P0GQB<@#1"0X,?^)QHM$)"")P0^LT`+!X1Z+
M5"0L"<&+1"0P`X0DL````(E,)#B)3"1(!9EY@EHQS2-L)"@S;"1`B>D!P8GP
MP>`%B40D((GPBVPD(`^L^!N)1"0P"VPD,(GH`<B)1"0@BT0D*(G!P>$>#ZS0
M`HG-"<6);"0PBU0D0`.4)+@```"+3"1$$XPDO````,=$)#0`````QT0D1```
M``")T`69>8):B<J+3"1(@](`B40D*#';B50D+(M4)#@QZ2'Q,<J)T`-$)"B)
MVA-4)"R)1"0HBT0D((E4)"R+5"0DQT0D+`````")P<'A!8E,)$")T8G"#ZS*
M&XM,)$")5"1("TPD2(G(`T0D*(GQ#ZS^`L'A'@GQB40D*(M$)#@#A"3`````
MB4PD0(E,)$@%F7F"6C'-(VPD(#-L)#"+?"0HBU0D),=$)#P`````QT0D)```
M``#'1"0T`````(GIBVPD+`'!B?C!X`6)1"0XBW0D.`^L[QL)_HGP`<@Q_XG&
MBT0D((G!P>$>#ZS0`HG-BU0D,(M,)$@)Q0.4),@```");"0XB6PD2(G0BU0D
M+`69>8):,>DC3"0HBVPD0#'-B>D!P8GPP>`%B40D((GPBVPD(`^L^!N)1"0P
M"VPD,(GH`<B)1"0@BT0D*(G!#ZS0`L'A'HM4)$0)P8M$)$`#A"30````$Y0D
MU````(E,)#")3"1@BVPD2,=$)$0`````!9EY@EJ#T@`QS3';(?4S;"0XB>D!
MP8M$)"`1TXM4)"2)3"0HB5PD+(M<)#B)P<=$)"P`````P>$%B4PD0(G1BVPD
M0(G"#ZS*&XGQ"=6)Z`-$)"C!X1X/K/X"B<V+3"1@"?4#G"38````BW0D/!.T
M)-P```")1"0HB6PD0(G8B?*+="0@!9EY@EJ#T@`QZ3';B=\ASC-T)#`!QHM$
M)"@1UXM4)"R)="0XB7PD/,=$)#P`````B<8/K-`;P>8%BU0D)(G!"?&)R`-$
M)#@Q_XG&BT0D((G!#ZS0`L'A'@G!B4PD.(M$)#`#A"3@````B4PD2(M4)"S'
M1"0D`````,=$)#0`````!9EY@EHQS2-L)"@S;"1`B>D!P8GPP>`%B40D((GP
MBVPD(`^L^!N)1"0P"VPD,(GH`<B)1"0@BT0D*(G!P>$>#ZS0`HG-BU0D0(M,
M)$0)Q0.4).@````3C"3L````B6PD,(G0!9EY@EJ)RHM,)$B#T@")1"0H,=N)
M5"0LBU0D.#'I(?$QRHG0`T0D*(G:$U0D+(E$)"B+1"0@B50D+(M4)"2)P<'A
M!8E,)$")T8G"#ZS*&XM,)$"+7"0XB50D2`M,)$C'1"0L`````(M4)"3'1"1$
M`````,=$)#P`````B<B)\0-$)"@/K/X"P>$>"?$#G"3P````B40D*(M\)"B)
M3"1(B4PD0(G8!9EY@EHQS2-L)"`S;"0PB>F+;"0L`<&)^,'@!8E$)#B+="0X
M#ZSO&PG^B?`!R#'_B<:+1"0@B<'!X1X/K-`"B<V+5"0PBTPD2`G%`Y0D^```
M`(EL)#B);"1(B=`%F7F"6C'I(TPD*(ML)$`QS8GI`<&)\,'@!8E$)"")\`^L
M^!N)1"0PBVPD(`ML)#"+5"0LQT0D)`````#'1"0T`````(GHBVPD2`'(B40D
M((M$)"B)P0^LT`+!X1Z+5"1$QT0D1``````)P8M$)$`#A"0``0``$Y0D!`$`
M`(E,)&")3"0P!9EY@EJ#T@`QS3';(?4S;"0XB>D!P8M$)"`1TXM4)"2)3"0H
MB5PD+(M<)#B)P<=$)"P`````P>$%B4PD0(G1BVPD0(G"#ZS*&XM,)&`)U8GR
MB>@#1"0HP>(>#ZS^`HG5"?4#G"0(`0``B40D*(EL)$");"1@BW0D((M4)"R)
MV`69>8):,>DASC-T)#")\0'!BT0D*(G&#ZS0&\'F!8M4)"3'1"0D`````(E$
M)#B+;"0XBT0D(`GU`>DQ_XML)&")SHE,)$B)P<'A'@^LT`*)RXM4)#`)PP.4
M)!`!``")7"0PB="+5"1$!9EY@EHQW2-L)"@S;"1`BUPD+(GI`<&)\,'@!8E$
M)"")\(ML)"`/K/@;B40D.`ML)#@!Z8E,)&")3"0@BTPD*(G(P>`>#ZS9`HG%
MBT0D0`G-`X0D&`$``(M,)#`3E"0<`0``B6PD.`6AZ]EN@](`,>F+;"1(,=O'
M1"0T`````#'-B>D!P8M$)"`1TXM4)"2)3"0HB5PD+(GSQT0D+`````")P<'A
M!8E,)$")T8ML)$")P@^LRAN+3"0H"=6)\@'IP>(>B=6+E"0@`0``B4PD2`^L
M^P*)3"0HBTPD,`G=@<*AZ]ENBUPD+(G0B6PD0(M4)"0!R#-L)#B)Z8ML)&`Q
MS8M,)"B)[@'&B<C!X`6)1"0PBT0D((ML)#`/K-D;B?,)S8G!`>O!X1X/K-`"
MB<V+E"0H`0``B5PD,`G%BT0D.(E<)&")[XML)$"!PJ'KV6Z)?"0X`=`Q_8M\
M)#")[HML)$@Q]8GIBVPD-`'!B?C!X`6)1"0@BW0D(`^L[QN+1"0HBU0D+`G^
MQT0D)`````#'1"0L``````'QB4PD2(E,)"")P<'A'@^LT`*)S8N,)#`!``"+
M5"0D"<6+1"1`B>Z+;"0X@<&AZ]ENB70D0`'(,?6)[HML)&`Q]8GI`<&+1"0@
MB<8/K-`;P>8%BU0D-(E$)"B+;"0HBT0D,`GU`>DQ_XG.B4PD8(G!P>$>#ZS0
M`HG+BY0D.`$```G#BT0D.(G=B5PD.(M<)$"!PJ'KV6X!T(M4)"0QZXML)$@Q
MW8GI`<&)\,'@!8E$)"B)\(ML)"@/K/@;B40D,`ML)#"+1"0@`>F)3"1(B4PD
M*(G!P>$>#ZS0`HG-"<6);"0PBY0D0`$``(N,)$0!``"+1"1`BVPD.('"H>O9
M;H/1`(G+B=$QT@'($=HS;"0PB40D((E4)"2+5"1@,=N)V8M$)"B+G"1(`0``
M,>H#5"0@$TPD)(E4)""+5"0LB4PD)(G!QT0D)`````#!X06)3"1`B=&+;"1`
MB<*+1"0X#ZS*&XM,)"`)U8M4)"0!Z8E,)"")3"1@B?'!X1X/K/X"B<T)]8'#
MH>O9;HGOBVPD,`'8B7PD.#']B>Z+;"1(,?6)Z0'!BT0D((G+B<8/K-`;P>8%
MB40D0(ML)$"+1"0H"?4!ZXG!,?^)7"1(BU0D+,'A'HG>QT0D+``````/K-`"
MBY0D4`$```G!BT0D,(G-BTPD.('"H>O9;HEL)$`!T(M4)"0QZ8ML)&`QS8GI
M`<&)V,'@!8E$)"B)V(ML)"@/K/@;B40D,`ML)#"+1"0@`>F)3"0HB4PD8(G!
MP>$>#ZS0`HN4)%@!``")S8N,)%P!```)Q8M$)#B);"0PBVPD0('"H>O9;H/1
M`(G+B=$QT@'($=HS;"0PB40D((E4)"2+5"1(,=N)V8M$)"@QZ@-4)"`33"0D
MB50D((M4)"R)3"0DB<'!X06)3"0XB=&+;"0XB<*+G"1@`0``BT0D0`^LRAN+
M3"0@QT0D)``````)U8M4)"0!Z8E,)$B)3"0@B?'!X1X/K/X"B<T)]8'#H>O9
M;HGOBVPD,`'8B7PD.#']B>Z+;"1@,?6)Z0'!BT0D((G&#ZS0&\'F!8M4)"S'
M1"0L`````(E$)$"+;"1`BT0D*`GU`>DQ_XG.B4PD8(G!P>$>#ZS0`HG+BY0D
M:`$```G#BT0D,(G=B5PD0(M<)#B!PJ'KV6X!T(M4)"0QZXML)$@QW8GI`<&)
M\,'@!8E$)"B)\(ML)"@/K/@;B40D,`ML)#"+1"0@`>F)3"1(B4PD*(G!P>$>
M#ZS0`HG-"<6);"0PBY0D<`$``(N,)'0!``"+1"0XBVPD0('"H>O9;H/1`(G+
MB=$QT@'($=HS;"0PB40D((E4)"2+5"1@,=N)V8M$)"B+G"1X`0``,>H#5"0@
M$TPD)(E4)""+5"0LB4PD)(G!QT0D)`````#!X06)3"0XB=&+;"0XB<*+1"1`
M#ZS*&XM,)"`)U8M4)"0!Z8E,)"")3"1@B?'!X1X/K/X"B<T)]8'#H>O9;HGO
MBVPD,`'8B7PD.#']B>Z+;"1(,?6)Z0'!BT0D((G+B<8/K-`;P>8%B40D0(ML
M)$"+1"0H"?4!ZXG!,?^)7"1(BU0D+,'A'HG>QT0D+``````/K-`"BY0D@`$`
M``G!BT0D,(G-BTPD.('"H>O9;HEL)$`!T(M4)"0QZ8ML)&`QS8GI`<&)V,'@
M!8E$)"B)V(ML)"@/K/@;B40D,`ML)#"+1"0@`>F)3"0HB4PD8(G!P>$>#ZS0
M`HN4)(@!``")S8N,)(P!```)Q8M$)#B);"0PBVPD0('"H>O9;H/1`(G+B=$Q
MT@'($=HS;"0PB40D((E4)"2+5"1(,=N)V8M$)"@QZ@-4)"`33"0DB50D((M4
M)"R)3"0DB<'!X06)3"0XB=&+;"0XB<*+G"20`0``BT0D0`^LRAN+3"0@QT0D
M)``````)U8M4)"0!Z8E,)"")3"0XB?'!X1X/K/X"B<T)]8'#H>O9;HGOBVPD
M,`'8B7PD0#']B>Z+;"1@,?6)Z0'!BT0D((G&#ZS0&\'F!8M4)"S'1"0L````
M`(E$)$B+;"1(BT0D*`GU`>DQ_XG.B4PD8(G!P>$>#ZS0`HN4))@!``")RXN,
M))P!```)PXM$)#")W8'"H>O9;HEL)$B#T0")RXG1,=(!R!':BUPD0#'KBVPD
M.#'=,=N)Z0'!B?`1T\'@!3'2B40D*(GPBVPD*`^L^!N)1"0P"VPD,(M$)"`!
MZ1'3B<J)P8E<)&R)5"1HP>$>B50D*(M4)"2)S8N,)*0!``#'1"0T``````^L
MT`*+E"2@`0``"<6+1"1`B6PD.(ML)$B!PJ'KV6Z#T0")RXG1,=(!R!':,VPD
M.(E$)"")5"0DBU0D8#';B=F+1"0HBYPDJ`$``#'J`U0D(!-,)"2)5"0@BU0D
M+(E,)"2)P<'A!8E,)#")T8ML)#")PHM$)$@/K,H;BTPD(`G5`>F)3"0PB4PD
M0(GQP>$>#ZS^`HG-BWPD,`GU@<.AZ]EN`=B+7"0XB6PD8#'KBVPD:#'=B>F+
M;"0T`<&)^,'@!8E$)""+="0@#ZSO&PG^B?`!R(E$)""+1"0HBU0D+(MT)&"+
M?"1`QT0D)`````")P<=$)"P`````QT0D3``````/K-`"P>$>BY0DL`$``(GS
MB<W'1"0\``````G%BT0D.('"H>O9;HEL)$@!T#'KBU0D)#'?BYPDO`$``(GY
M`<&+1"0@P>`%B40D*(M$)""+?"0H#ZS0&XM4)#2)1"0X"WPD.(GX`<B)1"0H
MBT0D,(G!#ZS0`L'A'@G!B?")SXE,)#B+C"2X`0``@<'<O!N/@],`,=(!R(M,
M)$@1V@G](VPD(#';(?F)S@GNB?$!P8M$)"@1TXM4)"R)3"0PB5PD-(G!P>$%
MB4PD0(G1BVPD0(G"#ZS*&PG5B>@#1"0PBU0D)#';BW0D2,=$)#0`````QT0D
M1`````")1"0PBT0D((G!P>$>#ZS0`HG-B?F)^@G%BT0D*`GI(>J);"1`(<B)
MQPG7`[0DP`$``(GYBWPD3!.\),0!``#'1"1,`````(GPB<X%W+P;CXGZB=^#
MT@`!QHM$)#`1UXM4)#2)="0@B7PD)(G&#ZS0&\'F!8M4)"R)P0GQB<@#1"0@
M,?^)QHM$)"B)P0^LT`+!X1X)P8M$)#B)R@G-B4PD2"-L)#")3"1@BTPD0"'1
M"<T#A"3(`0``B>D%W+P;CP'!B?#!X`6)1"0@B?`/K/@;B40D*(ML)"`+;"0H
MBU0D-,=$)"0`````QT0D-`````#'1"0\`````(GH`<@QVXE$)""+1"0PB<'!
MX1X/K-`"BU0D8(G-"<6);"0P">J)T(M4)$@A\"'J"="+5"1$B<&+1"1``X0D
MT`$``!.4)-0!```%W+P;CX/2``'!BT0D(!'3BU0D)(E,)"B)7"0LQT0D+```
M``")P<'A!8E,)#B)T8G"#ZS*&XM,)#B)5"1`"TPD0(G(`T0D*(GQP>$>B40D
M*(GP#ZSX`HM\)#`)P0G-(VPD((E,)#@ASXE,)&"+="1(BU0D),=$)$0`````
M"?T#M"38`0``BWPD*(GIBVPD+(GP!=R\&X\!P8GXP>`%B40D0(MT)$`/K.\;
M"?Z)\`'(,?\QVXG&BT0D((G!P>$>#ZS0`HG-BU0D8`G%BT0D*(EL)$`)ZB'0
MBU0D."'J"="+5"0TQT0D-`````")P8M$)#`#A"3@`0``$Y0DY`$```7<O!N/
M@](``<&)\!'3P>`%B4PD((G!B?"+5"0L#ZSX&XE<)"3'1"0D`````(E$)#`+
M3"0PB<@#1"0@,=N)1"0@BT0D*(G!#ZS0`L'A'@G!B<H)S8E,)#")3"1(BTPD
M0"'UBT0D."'1BU0D/,=$)#P`````"<T#A"3H`0``$Y0D[`$``(GI!=R\&X^#
MT@`!P8M$)"`1TXM4)"2)3"0HB5PD+,=$)"P`````B<'!X06)3"0XB=&+;"0X
MB<(/K,H;B?$)U8M4)$B)Z`-$)"C!X1Z)S3';B40D*(GPBW0D0`^L^`()Q8M$
M)"`)ZHEL)#@AT(M4)#")QR'J"=<#M"3P`0``B?F+?"1$$[PD]`$``(GPB<X%
MW+P;CXGZB=^#T@`!QHM$)"@1UXM4)"R)="1`B7PD1(G&#ZS0&\'F!8G!"?&)
MR`-$)$`Q_XG&BT0D((M4)"3'1"0D`````,=$)$0`````QT0D-`````")P0^L
MT`+!X1X)P8M$)#")RHE,)$")3"1("<V+3"0X(VPD*"'1BU0D+`G-`X0D^`$`
M`(GI!=R\&X\!P8GPP>`%B40D((GPBVPD(`^L^!N)1"0P"VPD,(GH`<@QVXE$
M)""+1"0HB<'!X1X/K-`"BU0D2(G-"<6);"0P">J)T(M4)$`A\"'J"="+5"0\
MB<&+1"0X`X0D``(``!.4)`0"```%W+P;CX/2``'!BT0D(!'3BU0D)(E,)"B)
M7"0LB<'!X06)3"0XB=&)P@^LRAN)5"1(BTPD.`M,)$C'1"0L`````(M4)"3'
M1"0\`````,=$)$0`````B<@#1"0HB?'!X1Z)1"0HB?"+="1`#ZSX`HM\)#`)
MP0G-(VPD((E,)#@ASXE,)$@)_0.T)`@"``"+?"0HB>F+;"0LB?`%W+P;CP'!
MB?C!X`6)1"1`BW0D0`^L[QL)_HGP`<@Q_S';B<:+1"0@B<'!X1X/K-`"B<V+
M5"1("<6+1"0HB6PD0`GJ(="+5"0X(>H)T(M4)#2)P8M$)#`#A"00`@``$Y0D
M%`(```7<O!N/@](``<&)\!'3P>`%B4PD((G!B?")7"0D#ZSX&XE$)#`+3"0P
MBU0D+,=$)"0`````QT0D-`````")R`-$)"`QVXE$)""+1"0HB<$/K-`"P>$>
M"<&+1"0XB<J)3"0PB4PD2`G-BTPD0"'U(=&+5"0\QT0D/``````)S0.$)!@"
M```3E"0<`@``B>D%W+P;CX/2``'!BT0D(!'3BU0D)(E,)"B)7"0LQT0D+```
M``")P<'A!8E,)#B)T8ML)#B)P@^LRAN)\0G5BU0D2(GH`T0D*,'A'HG-,=N)
M1"0HB?"+="1`#ZSX`@G%BT0D(`GJB6PD."'0BU0D,(G'(>H)UXGYBWPD1`.T
M)"`"```3O"0D`@``QT0D-`````")\(G.!=R\&X^)^HG?@](``<:+1"0H$=>+
M5"0LB70D0(E\)$3'1"1$`````(G&#ZS0&\'F!8M4)"3'1"0D`````(G!"?&)
MR`-$)$`Q_XG&BT0D((G!#ZS0`L'A'@G!BT0D,(G*B4PD0(E,)$@)S8M,)#@C
M;"0H(=&+5"0L"<T#A"0H`@``B>D%W+P;CP'!B?#!X`6)1"0@B?"+;"0@#ZSX
M&XE$)#`+;"0PB>@!R#';B40D((M$)"B)P<'A'@^LT`*+5"1(B<T)Q8EL)#`)
MZHG0BU0D0"'P(>H)T(G!BT0D.`.$)#`"``"+5"0\$Y0D-`(``,=$)#P`````
M!=R\&X^#T@`!P8M$)"`1TXM4)"2)3"0HB5PD+,=$)"P`````B<'!X06)3"0X
MB=&)P@^LRAN+3"0XB50D2`M,)$B+5"0DB<@#1"0HB?'!X1Z)1"0HB?"+="1`
M#ZSX`HM\)#`)P0G-(VPD((E,)#@ASXE,)$@)_0.T)#@"``"+?"0HB>F+;"0L
MB?`%W+P;CP'!B?C!X`6)1"1`BW0D0`^L[QL)_HGP`<@Q_S';B<:+1"0@B<'!
MX1X/K-`"B<T)Q8EL)$#'1"1$`````(M4)$B+1"0H">HAT(M4)#@AZ@G0BU0D
M-(G!BT0D,`.$)$`"```3E"1$`@``!=R\&X^#T@`!P8GP$=/!X`6)3"0@B<&)
M\(M4)"P/K/@;B5PD),=$)"0`````B40D,`M,)##'1"0L`````(G(`T0D(#';
MB40D((M$)"B)P0^LT`+!X1X)P8M$)#B)R@G-B4PD*(E,)&"+3"1`(?4AT8M4
M)#P)S0.$)$@"```3E"1,`@``B>D%W+P;CX/2``'!BT0D(!'3BU0D)(E,)#")
M7"0TB<'!X06)3"0XB=&+;"0XB<*)\,=$)#0`````#ZS*&XM,)##'1"0\````
M``G5BU0D8`'IB4PD2(E,)#")\0^L^`+!X1Z+="1`B<T)Q8M$)"`)ZHEL)&B)
M;"0X(="+5"0HB<<AZ@G7`[0D4`(``(M4)#2)^8GP!=R\&X\!P8M$)#")RXG&
M#ZS0&XM4)"3!Y@6)1"1`BVPD0(M$)"`)]0'KB<$Q_P^LT`+!X1Z+5"0LBVPD
M:`G!BT0D*`.$)%@"```3E"1<`@``B5PD8(G>B4PD0`76P6+*@](`,<V)1"0@
MB50D)(M4)$B)V#'JB=$#3"0@P>`%B40D((G8BVPD(`^L^!N+5"0TBUPD0(E$
M)"@+;"0HBT0D,,=$)"0``````>F)3"0@B4PD2(G!P>$>#ZS0`HG-BU0D/`G%
MBT0D.`.$)&`"```3E"1D`@``B6PD.`76P6+*@](`,>N+;"1@,=TQVXGI`<&+
M1"0@$=.+5"0DB4PD*(E<)"R)\\=$)"P`````B<'!X06)3"0PB=&+;"0PB<(/
MK,H;BTPD*`G5B?(!Z<'B'HG5BY0D:`(``(E,)&`/K/L"B4PD*(M,)$`)W8'"
MUL%BRHG0B6PD0`'(,VPD.(GIBVPD2(M<)"R+5"0DQT0D-`````#'1"0D````
M`#'-BTPD*(GN`<:)R,'@!8E$)#"+1"0@BVPD,`^LV1N)\XMT)$`)S8G!`>O!
MX1X/K-`"B<V+E"1P`@``B5PD,`G%BT0D.(M\)#");"0XB5PD2('"UL%BR@'0
M,>Z+;"1@BU0D+#'UB>F+;"0T`<&)^,'@!8E$)""+="0@#ZSO&XM$)"@)_@'Q
MBW0D.(E,)"")3"1@B<'!X1X/K-`"B<V+C"1X`@``BU0D)`G%BT0D0(GOB?6!
MP=;!8LJ)?"0X`<@Q_3-L)$B)Z0'!BT0D(,'@!8G'BT0D(`^LT!N)1"0HBVPD
M*(M$)#"+5"0TQT0D+`````#'1"0T``````G]`>F)3"1(B4PD*(G!#ZS0`HN4
M)(`"``#!X1Z)S0G%B?"!PM;!8LJ);"1``=`S;"0XBU0D+#-L)&")Z0'!BT0D
M*(G+B<:)QXM$)#C!Y@6)="0PBVPD,`^LUQL)_8M\)"`!ZXML)"3'1"0D````
M`(E<)#")7"1@B?J)_HM\)#0/K.X"P>(>B=6+E"2(`@``"?6+="1`B6PD.('"
MUL%BR@'0,>Z+;"1(,?6+="0PB>F)_0'!B?")]\'@!8E$)""+="0@#ZSO&XM$
M)"@)_@'QB4PD2(E,)"")P8M4)"S!X1Z+?"0XB<W'1"0L``````^LT`*+E"20
M`@``"<6+1"1`B>Z)_8'"UL%BRHET)#@!T#'U,VPD8(M4)"2)Z0'!BT0D((G+
MP>`%B40D*(M$)""+;"0H#ZS0&XM4)#3'1"0T`````(E$)$`+;"1`BT0D,`'K
MB<$/K-`"BY0DF`(``,'A'HE<)"B)S8E<)&`)Q8GX@<+6P6+*B6PD0`'0,VPD
M.(M4)"PS;"1(B>D!P8M$)"B)QHG'P>8%B70D,(ML)#`/K-<;"?V+?"0@`>F+
M;"0DB4PD2(E,)#")^HG^#ZSN`L'B'HG5BY0DH`(``(M$)#@)]8MT)$"+?"0T
MB6PD.,=$)"0`````@<+6P6+*`=`Q[HML)&"+5"0LQT0D+``````Q]8MT)#")
MZ8G]`<&)\(GWB<O!X`6)1"0@BT0D*(MT)"`/K.\;B<$)_HM\)#@!\\'A'@^L
MT`*)S8N4)*@"``")7"0@"<6+1"1`B5PD8(GNB?V!PM;!8LJ)="1H`=`Q]3-L
M)$B+5"0DB>D!P8M$)"#!X`6)1"0HBT0D((ML)"@/K-`;BU0D-(E$)#@+;"0X
MBT0D,`'IB4PD0(E,)"B)P0^LT`*+E"2P`@``P>$>B<T)Q8GX@<+6P6+*B6PD
M.`'0,?4S;"1@BU0D+,=$)#0`````B>D!P8M$)"B)RXG&B<>+1"1HP>8%B70D
M,(ML)#`/K-<;"?V+?"0@`>N+;"0DQT0D)`````")7"0PB5PD2(GZB?Z+?"0T
M#ZSN`L'B'HG5BY0DN`(```GUBW0D.(EL)&B!PM;!8LH!T#'NBVPD0(M4)"PQ
M]8MT)#")Z8G]`<&)\(GWP>`%B40D((MT)"`/K.\;BT0D*`G^BWPD:`'QB4PD
M((E,)&")P<'A'@^LT`*)S8N4),`"```)Q8M$)#B)[HG]@<+6P6+*B70D.`'0
M,?4S;"1(B>D!P8M$)"")R\'@!8E$)"B+1"0@BU0D)(ML)"C'1"0L``````^L
MT!N+5"0TQT0D-`````")1"1`BT0D,`ML)$")P0'KP>$>#ZS0`HN4),@"``")
MS8N,),P"```)Q8E<)$B)7"0HB?B);"1`@<+6P6+*@]$`B<N)T3'2`<@1VC-L
M)#@QVS-L)&")Z0'!BT0D*!'3BU0D+(G&B<>+1"0XP>8%B70D,(ML)#`/K-<;
M,=()_8M\)"`!Z8ML)"01TXE,)#")3"1@B?J)_HM\)#0/K.X"P>(>B5PD9(G5
MBY0DT`(```GUBW0D0(EL)#B!PM;!8LH!T#'NBVPD2#'UBW0D,(GIB?T!P8GP
MB?>)R\'@!8E$)""+="0@BT0D*(M4)"P/K.\;QT0D)`````#'1"0L``````G^
MB<&+?"0X`?/!X1X/K-`"BY0DV`(``(G-BXPDW`(```G%BT0D0(E<)"")7"1(
MB>Z)_8'"UL%BRH/1`(G+B=$QT@'($=HQ]3-L)&`QVXET)&")Z0'!BT0D(!'3
MBU0D),'@!8E$)"B+1"0@BVPD*`^LT!LQTHE$)#@+;"0XBT0D,`'I$=.+5"0T
MB4PD*(E,)$")P8E<)$3!X1X/K-`"BY0DX`(``(G-BXPDY`(```G%B?B);"0X
M@<+6P6+*@]$`B<N)T3'2`<@1VC'U,VPD2#';B>D!P8M$)"@1TXM4)"R)QHG'
MP>8%B70D,(ML)#")W@^LUQN)RS'2BT0D8`G]BWPD(,=$)#0``````>N+;"0D
MQT0D)``````1UHE<)#")7"1(B70D3(GZB?X/K.X"P>(>BWPD0(G5BY0DZ`(`
M``GUBW0D.(EL)&"!PM;!8LH!T#'NBU0D+#'WBW0D,(GYBWPD-`'!B?#!X`6)
M_8GWB40D((MT)"`/K.\;BVPD8`G^B?`!R(E$)""+1"0HB<$/K-`"P>$>BU0D
M,`G!BT0D.(G/BTPD-(G3B7PD0,'C'HG.B5PD*`^DUAX/K,H"P>D"B70D+(GN
MB4PD-(N,)/`"``")5"0P@<'6P6+*`<@Q_C-T)$B)\0'!BT0D(,'@!8G&BT0D
M((M4)"2+7"0H#ZS0&\'J&XE$)#B+?"0XB50D/`GWB?B+?"14`<B)P8M$)!@#
M3"00`T0D(`M<)##'1P0`````QT<,`````,='%`````#'1QP`````B0_'1R0`
M````B4<(B=@#!"2)1Q"+1"1``T0D"(E'&(GH`T0D6(E'((N$)/P"``!E,P44
M````=0N!Q`P#``!;7E]=P^@Q(```D%575E/H%]?__X'#IXT``(/L'(7`#X2>
M````BXL<`0``BPF%R8E,)`@/A(H````/M@B$R70%@/D]=48Q]HM\)`B++X7M
M="^)5"0,B40D!&:0@^P$5O]T)`Q5Z++3__^#Q!"%P'4'@'PU`#UT+(/'!(LO
MA>UUVX/$'(GH6UY?7<.0B<:#Q@$/M@Z$R70%@/D]=?$IQNNGC78`B?HK5"0(
MBT0D#(UL-0'!^@*)$(/$'(GH6UY?7<.-=@`Q[>NYC70F`%=6B<93Z$_7__^!
MPN:,``"#[!"+NAP!``"-7"0(9:$4````B40D##'`B=J)\.@.____A<!T,XM4
M)`B+!XT$D(M0!(72B1!TX9"-M"8`````@\`$BU`$A=*)$'7TB=J)\.C;_O__
MA<!US8M$)`QE,P44````=0>#Q!!;7E_#Z.X>``"-M"8`````C;PG`````%57
MB<564XG6Z,/5__^!PU.,``"#[#AEH10```")1"0H,<`QP(`Z/0^4P`'&5N@^
MT?__@\00B00DB>B-5"08Z&W^__^%P`^$#0$``(/L#(G'4.@:T?__@\00.P0D
M#X/>````BT0D&(T,A0````"+@QP!``")1"0$#[9%`(3`#X2E`0``/#T/A)T!
M``")Z.L&D(#Z/70*@\`!#[80A-)U\2GHBU0D!(/L#(LZ`<^+3"0,C40(`E#H
M5M'__X/$$(7`B0</A'4!``"+5"0$C4T!BP*+5"08BQ20#[9%`#P]B`)T(X3`
M=0_K'8GVC;PG`````#P]=!"#P0$/MD'_@\(!A,"(`G7LQ@(],<"-M"8`````
M#[8,!HA,`@&#P`&$R77Q,<"+7"0<93,=%`````^%%`$``(/$+%M>7UW#C;8`
M````@\8!#[9&_X/'`83`B$?_=>_KS)"-="8`BX,<`0``BQ")1"0$BSJ%_P^$
MP@```#'`ZPB-M@````")^(UX`8L,NH7)=?2-!(4,````BXMP$0``A<EU:XE4
M)`B#[`S'@W`1```!````4.ADT/__@\00A<`/A(4```"-#+T`````@^P$48M4
M)!")3"044HE$)!10Z)O0__^+3"04BT0D&(/$$(D!BTPD#(M$)`C'1+@$````
M`(E\)!CI?/[__Y"-="8`@^P(4%+H]LW__XM,)!2)1"08@\00A<")`70AC0R]
M`````.O"C70F`#'`Z7+^__^0N`@````Q_^E/____N/_____IV_[__^B5'```
MD(UT)@!55XG%5E/H==/__X'#!8H``('LC````&6A%````(E$)'PQP(7M=`:`
M?0``=2.+1"1\93,%%`````^%)P$``('$C````%M>7UW#C;0F`````(/L#%7H
M9\[__XE$)!"#Q!"%P'3)C8.QDO__B40D!(V#L)+__XE$)`B#[`S_="0,Z'S.
M__^#Q!"%P`^$L0```(U0$XM\)`2Y`@```(G6\Z9TUXM\)`BY`P```(G6\Z9T
MR(E4)`R#[`Q5Z&/.__^+5"0<B<:)%"2)5"0<Z%'.__^-1`8"B00DZ.7.__^)
MQEA:BU0D%(V#LY+__U)54&K_:@%6Z%K/__^#Q!R-1"0@4%9J`^BZS/__@\00
M@_C_=!"+1"0L)0#P```]`$```'0^@^P,5N@)SO__@\00@^P,5NA=S?__@\00
MZ3W___^0C70F`(/L#/]T)`SH-,[__XDL).B<SO__@\00Z='^__^)\.B=_O__
MZ\7H)AL``(VV`````%=6B<=3Z`;2__^!PY:(``"#[`R+L_P```#_-NC0S/__
M@\0,!3P!``!05VH#Z/_,__^#Q!"%P'0(6S'`7E_#9I"#[`S_-NBFS/__BX!,
M`0``@\00)0#P```]`$```'0?@^P,_S;HA\S__XN`3`$``(/$$"4`\```/0"@
M``!UNH/L"&H"5^BWS/__@\00A<`/E,!;#[;`7E_#D(VT)@````!55XG'5E/H
M9='__X'#]8<``('L,!```&6A%````(F$)"`0```QP(E4)`QH_P\``(V#N9+_
M_XUT)"164.C`S?__@\00A<`/CHT```"-:/^+D_P```"`?"P<`(L2=%.)Q8E4
M)`R#[`15:B]6Z.'-__^#Q!"%P(M4)`QT/H/L#%+HS<O__U565U#HM,S__X/$
M((N$)!P0``!E,P44````=4.!Q"P0``!;7E]=PXVV`````(7M=:N-="8`@^P,
M4NB/R___@\0,_W0D#%=0Z%'+__^#Q!#KNXUT)@"+@_P```"+$.O6Z)D9``")
M]HV\)P````!3Z'K0__^!PPJ'``"#[!2+@_P```#_,.A$R___C9.LE/__4HV3
MR)+___^S$`$``%)0Z%K-__^#Q"A;PY"-="8`5E/H.=#__X'#R88``(/L$(NS
M_````/\VZ`/+__^)!"3HF____UC_-NCSRO__6HV3793__UEJ`%)2C9/0C?__
M4HV3Y)+__U)0Z%/+__^#Q"1;7L.-M@````"-O"<`````55=64^C7S___@<-G
MA@``@>P<(```9:$4````B80D#"```#'`Z'?)__^-D\22__^#[`A24(V#^9+_
M_U!H`1```&H!C70D)E;H9,S__X/$'&@`$```C;PD$Q```%=6Z`[,__^#Q!"%
MP'A'B<:-0`&#[`Q0Z*G+__^#Q!"%P(G%=!.#[`165U#HY<K__\9$-0``@\00
MBXPD#"```&4S#10```")Z'4/@<0<(```6UY?7<,Q[>O?Z#<8``"-M"8`````
MZ3O___^-="8`C;PG`````%575E/H!\___X'#EX4``('L/!```(N\)%`0``"-
M5"0HB[0D5!```&6A%````(F$)"P0```QP(V#!9/__XE\)`SHJ_?__X/L"(G%
M:B]7Z`[)__^#Q!"%P'0WBWPD#(V##I/__XGZZ-;X__^)^(N4)"P0``!E,Q44
M````#X6@`0``@<0\$```6UY?7<.0C70F`(/L#/]T)!CH%,K__UI9B40D'(V#
M&Y/__XE$)!A05NC=RO__@\00A<")QG2=C8.QDO__@#X`B40D'(N#_````(E$
M)!@/A.@```"-M"8`````A>UT%8/L"%95Z&++__^#Q!"%P`^$I````(/L#%;H
MKLG__X/$$(!\!O\O=1*-="8`@^@!@'P&_R_&!`8`=/*+3"04C40(`3W_#P``
M#X\H____C8,=D___@^P$_W0D$%"-@QB4__]64&@`$```:@&-="1(5NB(RO__
M@\04BWPD)/\WZ(K(__^#Q`P%/`$``%!6:@/HV<?__X/$$(7`=1^#[`S_-^AH
MR/__BX!,`0``@\00)0#P```]`(```'13@^P(_W0D&&H`Z.7)__^#Q!"%P(G&
M#X2A_O__@#X`#X4?____A>UT$XM\)!RY`@```(GN\Z9TR8UT)@"+="0<N`$`
M``#I./___XUV`(V\)P````"#[`AJ`5;H1<C__X/$$(7`=9N-@PZ3__^)\N@Q
M]___@^P,5N@HRO__@\00Z4S^___H^Q4``(UT)@"-O"<`````BU0D!`^V"HG0
MA,ET&XUV`(/"`8#Y+P^V"@]$PH3)=?#SPXVV`````//#C;8`````5E/HJ<S_
M_X'#.8,``(/L%(MT)""%]G0X#[86A-)T,8A4)`^#[`Q6Z"3(__^-1`;_@\00
M#[94)`\YQG(+ZSYFD(/H`3G&=#F`."]T].LG9I"-@[&2__^#[`Q0Z(')__^#
MQ!"#Q!1;7L.0C;0F`````(`X+W0P@^@!.<9R]#G&=26`^B]TRXV#'9/__X/L
M#%#H3,G__X/$$.O)C;0F`````(`X+W4'@^@!.<9R]"GPC5`"@?H`$```=R>#
MP`%H`!```%!6C;-P`0``5NCAQ?__@\00B?"#Q!1;7L.-M@`````QP.E[____
MB?:-O"<`````5U93Z+C+__^!PTB"``"#[#!EH10```")1"0L,<"+@XB4__^-
M="0$B40D"HN#C)3__XE$)`Z+@Y"4__^)1"02BX.4E/__B40D%HN#F)3__XE$
M)!J+@YR4__^)1"0>BX.@E/__B40D(HN#I)3__XE$)"8/MX.HE/__9HE$)"J-
M@Q^3___HV/3__XV#*)/__^C-]/__C8,PD___Z,+T__^-@SF3___HM_3__XV#
M0)/__^BL]/__C8-0D___Z*'T__^-@P63___HEO3__XV#7)/__^B+]/__C8-F
MD___Z(#T__^-@W"3___H=?3__XV##I/__^AJ]/__C8-ZD___B?+HG?/__X7`
M=`V)PHV#9I/__^C<]/__C8.+D___B?+H?_/__X7`=`V)PHV#G9/__^B^]/__
MC8.HD___B?+H8?/__X7`=#6)PHV#!9/__^B@]/__C9/4D___C8-`D___Z(_T
M__^+1"0L93,%%````'51@\0P6UY?PXUV`(V#N)/__XGRZ!OS__^%P'4GC70D
M&XV[R9/__[D*````\Z9UM(U4)"6-@UR3___H1?3__^NCC78`B<*-@UR3___H
M,_3__^N1Z`P3``"-M@````"-OP````!3Z.K)__^!PWJ```"#[!AEH10```")
M1"0,,<"+@S@!``"#^/]T&HM,)`QE,PT4````=3Z#Q!A;PY"-M"8`````C50D
M"(V#7)/__^B!\O__B<(QP(72=!(/MA*`^C`/E<$QP(32#Y7`(<B)@S@!``#K
MM>B*$@``C78`C;PG`````%/H:LG__X'#^G\``(/L".@\Q?__@^P,4.@3Q?__
M@\00A<!T#(L`@\0(6\.0C70F`#'`Z_*-M@````"-OP````!55U93Z"?)__^!
MP[=_``"#[!QEH10```")1"0,,<"-5"0(C8/6D___BWPD,.C?\?__A<!T:X`X
M`(G&=&2#[`A74.@:Q?__@\00A<!U8(/L#%?H>L3__XG%B30DZ'#$__^-1`4"
MB00DZ`3%__^)Q8V#&Y/__X/$#%90C8,8E/__5U!J_VH!5>AUQ?__C8/6D___
M@\0@B>KHQ?+__^L0C78`C8/6D___B?KHL_+__XM$)`QE,P44````=0B#Q!Q;
M7E]=P^AY$0``B?:-O"<`````55=64^A7R/__@</G?@``@>P\@0``BX0D4($`
M`(U4)#R-L^:3___'1"1(`````,=$)&P`````B70D3,=$)%0`````B40D$(E4
M)`AEH10```")A"0L@0``,<"-@_*3__^)1"1`C8.QDO__B40D1(V#G9/__XE$
M)`2)1"18C8.6D___B40D7(V#]Y/__XE$)&"-@[.3__^)1"1DC8/_D___B40D
M:(V#`Y3__XE$)%"-@P63___HB/#__X7`=`F`.``/A2L"``#H)O[__X7`B<4/
MA&0"``"#[`Q5Z"/#__^-1``!B00DZ+?#__^)1"00@\00@'T``'0LBS0DC;L,
ME/__D`^V10"#[`R#Q0%05VK_:@%6@\8"Z!?$__^#Q""`?0``==Z-?"18BT0D
M!(ML)`CK#8/'!(L'A<`/A&L!``")ZNC\[___A<")QG3F@#@`=.'H_/3__X7`
M=-B#[`Q6Z"_$__^#Q!"%P(G&#X0Z`0``9I")\(L(@\`$C9'__O[^]]$ARH'B
M@("`@'3IB='!Z1#WPH"````/1-&-2`(/1,&)T0#1BPPD@]@#*?"+.8/!!(V7
M__[^_O?7(?J!XH"`@(!TZ8G7BRPDP>\0]\*`@```#T37C7D"#T7YB=$`T8/?
M`X/L#"GOC;PX!`0``%?HL,+__XE$)!")P8V#$93__U50C8,=D___B40D.%"-
M@Q:4__]6B<Y0:O]J`5'H$\/__X/$*&C``0``5N@%P/__@\00@_C_=1#HV+__
M_XL`@_@1#X5_"0``B[/\````@^P,_S;H[<#__X/$#`4\`0``4/]T)`AJ`^@9
MP?__@\00A<")Q0^$+`$``(/L#/]T)`R+1"0@_S"-@_24__]0BX,8`0``:@'_
M,.CIO___@\0@QT0D!`````#K;(UT)@`Q_XVV`````(MTO$"%]G0P@#X`="N)
M\(/'`>B)\___A<!TY8/L#%;HO,+__X/$$(7`=-6)QNF._O__C;8`````,?;I
M@?[__Y"#[`Q0B40D$.@S_/__BT0D$(D$).B'PO__B40D%(/$$(N,)"R!``!E
M,PT4````BT0D!`^%A`D``('$/($``%M>7UW#D(UT)@")\#'_A<!T'8M4)`B#
MQP'H].W__X7`=`6`.`!U*XM$O$R%P'7C@^P,C:OKD___:@WH,\'__XE$)!"#
MQ!#I??W__XVT)@````"#[`Q0Z`?"__^#Q!"%P'3%B<7I/?W__XGVC;PG````
M`(/L#/\VZ):___^+@$P!``"#Q!`E`/```#T`0```#X6Q_O__@^P,_S;H<[__
M_XN`5`$``(E$)!3H9,#__X/$$#E$)`0/A8O^__^#[`S_-NA-O___BX!,`0``
M@\00)?\!```]P`$```^%:/[__X/L#%?HB\#__XM4)!B)1"04C8/AD___Z!CM
M__^#Q!"%P`^$70$``(/L#%#H5,'__UY?4(M$)!S_,.@&]?__B40D&(/$$(7`
M#X0W`0``@^P,BWPD%%?HFK___X/$$(/X`W8RB7PD"(UT!_R-NQ^4__^Y!0``
M`/.F=1N#^`0/A+(&``"+?"0(@'P'^R\/A*,&``"-=@#HR_G__X7`=1V#[`AJ
M`/]T)!3HJ<#__XE$)""#Q!"%P`^%V@```(V3U)/__XVS793__XV#7)/__XV[
M1I3__^BM[?__Z#B]__]64(V#.)3___]T)"C_="0,4&K_:@'_="0@Z"K`__^#
MQ"")="0(BW0D!.LVD(UT)@#H\[S__X,X$74]Z/F\__^#Q0&#[`S_="0455#_
M="0X_W0D'%=J_VH!5NCJO___@\0P@^P(:,`!``!6Z-F\__^#Q!"#^/]TN8/L
M#/]T)`SH!;[__XM\)!2-@P63__^)^N@4[?__B3PDZ*SY__^#Q!#IA/W__XUT
M)@"+1"00BP")1"0(Z;K^__^0:@)J_VKNBWPD'%?H(+W__X/$#&H&C80D-`$`
M`(E$)!!05^B)O?__@\00@+PD+`$```!U#H"\)"T!``!##X0Q!@``:@!J`&H`
M_W0D'.C?O/__QX0D@`````$C16?'A"2$`````````,>$)(@```")J\WOQX0D
MC`````````#'A"20````_MRZF,>$))0`````````QX0DF````'94,A#'A"2<
M`````````,>$)*````#PX=+#QX0DI`````````#'A"2H`````````,>$)*P`
M````````QX0DL`````````#'A"2T`````````,>$)/@`````````@\00C40D
M<(E$)"R-A"2H````B40D)(UT)@"#[`1H`(```/]T)!#_="0<Z(N\__^#Q!"%
MP(G%#X[N`0``B[0DF````(N\))P```")Z)G!X`.);"08B50D'(N,)*0````!
M\(/_`(N4)*````!W!#G&=@:#P@&#T0"+?"0<BW0D&(F$))@```"+A"3H````
MQX0DG``````````/K/X=P>\=`=81SX7`B;0DH````(F\)*0````/A&$!``"Z
M0````"G".=4/3M4#1"0D@^P$4O]T)!")UU#H@;S__XN$)/@````!^(F$)/@`
M``"#Q!"#^$`/A27___^+1"0L*?T#?"0(Z,;!__^-M@````"#_3\/CN@```"#
M[4")Z(EL)"B)_<'H!HUP`8E$)!C!Y@8!_HM\)"R)]HV\)P````"+10"#Q4")
MA"2H````BT7$B80DK````(M%R(F$)+````"+1<R)A"2T````BT70B80DN```
M`(M%U(F$)+P```"+1=B)A"3`````BT7<B80DQ````(M%X(F$),@```"+1>2)
MA"3,````BT7HB80DT````(M%[(F$)-0```"+1?")A"38````BT7TB80DW```
M`(M%^(F$).````"+1?R)A"3D````B?CHYL#__SGU#X5.____BT0D&(GOBVPD
M*,'@!BG%:D155_]T)##HDKK__XFL)/@```"#Q!#I`_[__XUV`(M\)`CIY_[_
M_XVT)@````"#[`S_="0<Z*2[__^+E"2L````BX0DJ````(N\)+````"+K"2T
M````B40D&(E4)!P/K-`#B7PD((EL)"2#X#^-4`'&A`2X````@(/$$(/Z.`^/
M=0(``+@X````,?\IT`-4)"2#^`0/@Z\"``"%P'0+J`+&`@`/A64#``"+?"00
MBVPD%(GX#ZSH&(B$).````")^`^LZ!"+;"0,B(0DX0```(GXBWPD"(BD).(`
M``"(A"3C````B?@/K.@8B(0DY````(GX#ZSH$(B$).4```")^(BD).8```"(
MA"3G````BT0D+.BXO___BW0D<(M\)'2)\HGQ#ZSZ&(BL)/$```"(C"3R````
M#[;"B)0D[P```(GRBW0D>`^L^A"+?"1\B)0D\````(GRB?&(K"3U````B(PD
M]@````^L^AB(E"3S````B?*+M"2`````#ZSZ$(N\)(0```"(E"3T````B?*)
M\8BL)/D```"(C"3Z````#ZSZ&(B4)/<```")\HNT)(@````/K/H0B[PDC```
M`(B4)/@```")\HGQB*PD_0```(B,)/X````/K/H8B)0D^P```(GRB[0DD```
M``^L^A"+O"24````B)0D_````(GRB?&(K"0!`0``B(PD`@$``(V,)`,!```/
MK/H8B4PD$(G-C8PD*P$``(B4)/\```")\HVT)/`````/K/H0B4PD"(V[#)3_
M_XB4)``!``#I#0```(VT)@`````/M@:#Q@&#[`Q05VK_:@%5@\4"Z#"Z__^#
MQ"`Y;"0(==^-@UV4___&A"0K`0```%"-@RF4____="04_W0D*/]T)`Q0:O]J
M`?]T)"#H^+G__X/$(.D?^O__BT0D$(M0!(72#X11^?__@^P,4HE4)"#HI+C_
M_X/$$(/X`P^&./G__XM4)!"-NR24__^Y!0```(UT`OSSI@]%5"0(B50D".D5
M^?__BTPD)+A``````=$IT'0-,=+&!!$`@\(!.<)R]8M$)"SHL+W__XM\)"2Y
M#@```#'`\ZOI>?W__X/L"%#_="0,BT0D(/\PC8.XE/__Z:SV__^-2@3'`@``
M``#'1`+\`````(/A_"G*`<*#XOR#^@0/@CS]__^#XOPQP(D\`8/`!#G0<O;I
M*/W__X"\)"X!``!!#X7!^?__@+PD+P$``$,/A;/Y__^`O"0P`0``2`^%I?G_
M_X"\)#$!``!%#X67^?__:@)J_VK&BW0D'%;H=;;__X/$#&HIBWPD$%=6Z.6V
M__^-@UV4__]0C8,IE/__5_]T)#C_="0<4&K_:@'_="0PZ*&X__^#Q##IR/C_
M_XGVC;PG`````#'M9HEL`O[IC_S__^B_!```ZPV0D)"0D)"0D)"0D)"055=6
M4^B7N___@<,G<@``@^PXB[O\````9:$4````B40D*#'`_S?H5;;__UW_-XG&
MZ$NV__\/ME9HB%!IC40D*(E$)!R)PHV#0)/__^@OY/__@\00A<!T"8`X,0^$
MKP(``.AZ[___@^P,_S?H$+;__XV35Y3__VH+:@%24.B_M?__@\0@A<`/A/X`
M``"+0`R#NW@1```!BR^+0!B)1"0(#X[G````,?;K/8VT)@````"+0@R#[`B-
M5@%0BX-T$0``_S20B50D%.@4N/__@\00A<"+BW@1``!U;XM4)`2-0@&)UCG!
M?F*#[`Q5Z)&U__]J`%;_="0@4.B4MO__@\0@A<!T/8L0BR^+0@@E``0@`#T`
M!```=)J)5"0$@^P,5>A=M?__:@)J`(M4)!Q24.C.M___BR^#Q"#I=____XUT
M)@"+BW@1``"++XU!_SGP=3V#^0%^.(GHO@$```"+;"0(ZPF-M"8`````BP>#
M[`R#Q@%0Z`JU__]:6550Z+&T__^#Q!`YLW@1``!_WHLO@^P,5>CKM/__C9-<
ME/__:@-J`5)0Z)JT__^#Q""%P(G&=#*+0`R#[`R+*/\WZ,*T__^-DUZ4__^#
MQ`Q255#H@;3__XM&#(/$$(LP]D8*0`^%;P$``(/L#/\WZ)6T__^-DV.4__]J
M`VH!4E#H1+3__X/$((7`B<9T-HM4)`R-@PZ3___H;.+__X7`B<4/A`(!``"+
M1@R#[`R+,/\WZ%.T__^#Q`Q55E#H&+3__X/$$(/L#/\WZ#NT__^-DV64__^#
MQ`QJ`5)0Z#FS__^)QEC_-^@?M/__C9-ZE/__@\0,4E90Z-ZS__]:_S?H!K3_
M_XM4)!S&0&D`C8,%D___Z//A__^#Q!"%P(G&B8-\$0``=$2#[`AHP`$``%;H
MQK+__XU0`8/$$(/Z`78)@_@1#X6R````BT0D'&4S!10````/A9P```"#Q"Q;
M7E]=PXGVC;PG`````(/L#/^S=!$``.A2\/__@\00A<")QHF#?!$``'6?C8-(
ME?__@^P,4.A$M?__C70F`(!X`0`/A$S]___I0OW__Y"+@W01``"#[`R+*(M&
M#(LP_S?H2;/__XGJB?#H\.;__X/$$.GS_O__D(VT)@````"#[`S_-^@FL___
M65U64.B-M/__@\00Z7;^___H0`$``%"+@W01``!6_S"-@VR5__]0Z,JT__^-
M=@"-O"<`````5U93BUPD$.AC````@<>4;@``@^P,4^A%Z___#[80@\00B<:$
MTG09B?:-O"<`````@\`!@/HO#[80#T3PA-)U\.C;[?__A=MT&(7`=!2`.P!T
M#XV_$93__[D$````\Z9T!%M>7\.)V%M>7^DAY/__BSPDPV:09I!FD&:09I!F
MD)!3Z(JW__^!PQIN``"#[`C_LS0!``#_="0<_W0D'/]T)!SHRK'__X/$&%O#
M9I!FD)!55U93Z%>W__^!P^=M``"#[`R+;"0HC;/<_O__Z+NP__^-@]C^__\I
MQL'^`H7V="4Q_XVV`````(/L!%7_="0L_W0D+/^4N]C^__^#QP&#Q!`Y_G7C
M@\0,6UY?7<.-=@#SPV:09I!FD&:09I!FD&:04^CJMO__@<-Z;0``@^P(Z#RS
M__]3@^P(Z-.V__^!PV-M``"#Q`A;PP,````!``(`+BX`)7,O)7,`+W!R;V,O
M<V5L9B]E>&4`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L
M<SHZ4$%2.CI"3T]4`"]P<F]C+R5I+R5S`%!!4E]414U0`%!!4E]04D]'3D%-
M10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]05`!015),24\`4$%27TE.
M251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%2
M7T-!0TA%`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%2
M7U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@!005)?
M0TQ%04X]`#$`3$1?3$E"4D%265]0051(`%5315(`4UE35$5-`"]T;7``5$5-
M4$1)4@!435``55-%4DY!344`)3`R>`!P87(M`"5S)7,E<R5S`'!A<FP`+G!A
M<@`E<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U
M)7,`05)'5@`8`'!E<FP`,`!005(Z.E!A8VME<CHZ5D524TE/3@`Q+C`T,P`M
M90`M+0```%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@`````'!E
M<FQX<VDN8P```"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R
M>2`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C
M=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y
M('EO=7(@;W!E<F%T:6]N*0H``%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER
M96-T;W)Y`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I
M<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````979A;"`G97AE8R`O
M=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U
M;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H
M)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%
M3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I
M<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H
M<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*1FEL93HZ1FEN
M9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL
M("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M
M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ
M5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I5
M3DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI
M;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;
M(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX
M/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N
M("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY("1C;60@/2`D
M=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PIC;&]S92`D
M=&UP.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD
M('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M<"T^9FEL96YA
M;64I.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@
M9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN
M:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#
M;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G
M.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\
M3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H
M)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R
M;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D
M871A7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P
M96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D[
M"FUY("1B=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D;V9F<V5T
M(#T@-3$R.PIM>2`D:61X(#T@+3$["G=H:6QE("@Q*0I["B1O9F9S970@/2`D
M<VEZ92!I9B`D;V9F<V5T(#X@)'-I>F4["G-E96L@7T9(+"`M)&]F9G-E="P@
M,B!O<B!D:64@<7%;<V5E:R!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A73L*
M;7D@)&YR96%D(#T@<F5A9"!?1D@L("1B=68L("1O9F9S970["F1I92!Q<5MR
M96%D(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=('5N;&5S<R`D;G)E860@
M/3T@)&]F9G-E=#L*)&ED>"`](')I;F1E>"@D8G5F+"`B7&Y005(N<&U<;B(I
M.PIL87-T(&EF("1I9'@@/CT@,"!\?"`D;V9F<V5T(#T]("1S:7IE('Q\("1O
M9F9S970@/B`Q,C@@*B`Q,#(T.PHD;V9F<V5T("H](#(["GT*;&%S="!U;FQE
M<W,@)&ED>"`^/2`P.PHD;V9F<V5T("T]("1I9'@@+2`T.PIS965K(%]&2"P@
M+21O9F9S970L(#(["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@+21O
M9F9S970@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L
M(#0["B1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L
M:7-T.PIW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L
M(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U
M;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN
M86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<
M9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT
M*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(
M+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD[
M"FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX
M?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1C<F,D97AT
M(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN
M86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL
M96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\
M7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@
M)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8F%S96YA;64D97AT(BP@)&)U9BP@
M,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD
M<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE
M0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C
M+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*
M?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`
M7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D9FEL
M96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R![
M"FUY("1K97D["F9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PIN97AT
M('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]("1?.R!L87-T.PI]"F1E
M;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["GT@
M;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE
M+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)
M3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I
M;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D9FEL96YA
M;64M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*96QS
M92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&9I;&5N86UE+3Y[8W)C
M?2YP;2(L("1F:6QE;F%M92T^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPG+"`D
M9FEL96YA;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE;F%M93H@)"$B.PIB
M:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG
M(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@
M0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H
M:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I
M6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]
M?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*
M<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE
M<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L
M971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D
M8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@
M+2`T.PI]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F
M:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@
M(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*
M)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R
M=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF
M="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@
M:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@
M("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM
M<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@
M<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R
M"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@
M+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q
M("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@
M)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU
M;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD
M;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I
M=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]
M"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@
M97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@
M0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD
M8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@
M/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII
M;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?
M*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?
M:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM
M>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["D%R8VAI=F4Z.EII<#HZ<V5T
M0VAU;FM3:7IE*#$R."HQ,#(T*3L*;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O
M<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D[
M"F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M
M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E860@)R1P87(G
M(&5R<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY
M("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@
M/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T
M82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C86P@)"\@/2!<
M-#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R
M(&1I92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N
M;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*
M?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*
M)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,
M62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@)"$[
M"F)I;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D
M871A7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]
M('-C86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L
M;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P
M;'DH7"1L;V%D97(L("0P*0I]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES
M("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`]
M(&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`](")?
M7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")005)?
M(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@
M*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N
M9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O(#T@
M=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U
M:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG
M<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ
M0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[
M<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK
M(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E
M24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*
M;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@
M*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H
M)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]
M("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:
M+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I
M9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY("1R
M968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@
M)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O
M)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T
M.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R
M:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE
M(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A086-K
M:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q
M*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N
M=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L
M("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E
M*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I
M"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M
M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA
M<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET
M=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R
M:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT
M*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#
M,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@
M;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]
M"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE
M7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H
M95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@
M)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(
M02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$
M:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V
M86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V
M97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2![
M"B1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["GT*96QS92![
M"FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*8FEN;6]D
M92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD
M8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64[
M"GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?
M;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A
M8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L
M96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PHD
M9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U
M;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E
M<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*
M<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM
M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F:"`]($E/.CI&:6QE
M+3YN97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B
M)"$Z("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N
M86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B
M.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD
M<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*
M;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D[
M"FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E
M="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM
M96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D
M;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@
M)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N
M9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO
M*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D
M97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]
M+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]
M/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP
M<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A
M="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG
M("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE
M>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D
M97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D
M4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S
M($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M
M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\
M+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345]
M(#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T
M95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA
M;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N
M86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE
M.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D
M<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E
M7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR
M97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI
M;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P
M.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A
M=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@
M1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A
M9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U
M:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E
M($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V
M>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E
M<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@
M>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I
M;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*
M979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A
M;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T[
M"F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"![
M"FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0
M?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E
M86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@
M5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP
M("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A
M=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A
M;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII
M9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@
M/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I
M('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D
M14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U
M<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N
M9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD
M:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M
M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D
M9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A
M9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS
M965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@
M/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE
M+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@
M1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@
M979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@
M?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D52
M4TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S
M:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D<')O9VYA
M;64L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E
M;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X
M+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I<B`N/2`B
M)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I
M9V5S="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[
M4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT
M96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D
M<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U
M8B!?=&5M<&9I;&4@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@
M0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@
M*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D
M(CL*;W!E;B!M>2`D9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@
M=W)I=&4@)'1E;7!N86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@
M)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@
M:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE
M*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]
M"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/
M1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P
M<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!
M4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@
M/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H
M)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6
M>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M
M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O
M;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E
M='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP
M871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.
M5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@
M/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L
M87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF
M:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O
M9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G
M;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE
M9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F
M5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H
M;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[
M7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@
M*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@
M96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@
M4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@
M05)'5E\P("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ
M=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD
M7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=0
M05)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%2
M7T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI
M('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D
M14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D
M<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,
M14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*
M?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*
M<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]
M"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@
M9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R
M8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E
M;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR
M97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!
M4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P
M96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D
M:7)E8W1O<GE<;BD*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE
M.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<
M*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*
M?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?
M7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$[
M"E]?14Y$7U\*``$;`SOP````'0```"QQ__\,`0``_'3__S`!```,=?__>`T`
M`(QX__]$`0``;*#__X@!```LH?__[`$``+RA__\D`@``#*3__Z0"``!\I?__
M7`,``!RF___,`P``#*?__V@$``!,I___F`0``*RG___D!```;*C__W0%``!\
MJ/__B`4``*RJ__^$!@``W*K__Y@&``#,J____`8``)RM__\T!P``'*[__U@'
M``!<KO__A`<``"RO___P!P``[+O__[P+``!\O___,`T``.N____`#0``_+__
M_]0-```LP/__``X``(S`__],#@``G,#__V`.```4``````````%Z4@`!?`@!
M&PP$!(@!```@````'````!AP___0`P````X(1@X,2@\+=`1X`#\:.RHR)"(0
M````0````,1S__\0`````````$````!4````0'?__]\G````00X(A0)!#@R'
M`T0.$(8$00X4@P5&#J`&`\@G"@X40<,.$$'&#@Q!QPX(0<4.!$$+````8```
M`)@```#<GO__O`````!!#@B%`D$.#(<#00X0A@1!#A2#!4X.,`)!#C1!#CA$
M#CQ!#D!(#C!7"@X40\,.$$'&#@Q!QPX(0<4.!$(+;@H.%$/##A!!Q@X,0<<.
M"$'%#@1$"S0```#\````.)___X(`````00X(AP)!#@R&`T,.$(,$3@X@`F8*
M#A!!PPX,0<8."$''#@1!"P``?````#0!``"0G___2P(```!!#@B%`D$.#(<#
M0PX0A@1!#A2#!5`.3%<.4$@.0%D.3$,.4$@.0`)/#DQ-#E!(#D`">`H.%$'#
M#A!!Q@X,0<<."$'%#@1'"P)<#DQ+#E!(#D!2#D1!#DA)#DQ%#E!0#D!C#DA!
M#DQ!#E!0#D````"T````M`$``&"A__]J`0```$$."(4"00X,AP-##A"&!$$.
M%(,%40Z@`6T*#A1!PPX00<8.#$''#@A!Q0X$2`M##JP!00ZP`4P.H`%;#JP!
M1`ZP`4@.H`%P#JP!00ZP`68.K`%!#J@!2PZL`4$.L`%!#K0!0@ZX`4(.O`%!
M#L`!2`ZD`44.J`%!#JP!0@ZP`4@.H`%8#JP!00ZP`4@.H`%##JP!00ZP`4@.
MH`%-#JP!1`ZP`5`.H`$`;````&P"```8HO__F`````!!#@B'`D$.#(8#0PX0
M@P1.#AQ(#B!(#A1&#AA!#AQ"#B!(#A!%"L,.#$/&#@A!QPX$0PM##AQ"#B!.
M#A!/#AQ"#B!.#A!/#AA"#AQ!#B!(#A!&PPX,1,8."$''#@0``)@```#<`@``
M2*+__^<`````00X(A0)!#@R'`T,.$(8$00X4@P51#L0@6`[(($L.S"!!#M`@
M2`[`(&,.Q"!!#L@@0@[,($$.T"!(#L`@2P[,($$.T"!&#M0@00[8($$.W"!!
M#N`@2`[`(%8*#A1!PPX00<8.#$''#@A!Q0X$1PM+#LP@00[0($@.Q"!$#L@@
M00[,($$.T"!(#L`@`"P```!X`P``G*+__SL`````00X(@P).#AQ(#B!,#B1,
M#BA!#BQ!#C!(#@A!PPX$`$@```"H`P``K*+__U,`````00X(A@)!#@R#`TX.
M'$@.($X.'$(.($8.'$<.&$(.'$$.($$.)$<.*$<.+$$.,$@.#$'##@A!Q@X$
M``",````]`,``,"B__^Y`````$$."(4"00X,AP-!#A"&!$$.%(,%40ZP0%T.
MN$!!#KQ`00[`0$<.Q$!%#LA`0@[,0$4.T$!(#K1`10ZX0$@.O$!!#L!`2`ZP
M0$P.O$!!#L!`2`ZP0$D.M$!!#KA`00Z\0$$.P$!-#K!`6`H.%$'##A!!Q@X,
M0<<."$'%#@1!"P`0````A`0``/"B__\%`````````/@```"8!```[*+__R4"
M````00X(A0)!#@R'`T$.$(8$00X4@P51#M`@<P[8($0.W"!!#N`@2`[0('$*
M#A1!PPX00<8.#$''#@A!Q0X$1@M##MP@1`[@($8.W"!!#M@@3P[<($$.X"!(
M#M`@<0[8($$.W"!!#N`@2`[0($L.W"!!#N`@2`[0('4.U"!$#M@@00[<($<.
MX"!!#N0@10[H($(.["!%#O`@2`[<($8.X"!(#M0@1@[8($$.W"!"#N`@2`[0
M($<.W"!"#N`@3@[0($\.V"!$#MP@0@[@($@.T"`"10[8($(.W"!!#N`@2`[0
M(%0.W"!!#N`@2`[0(!````"4!0``(*3__RH`````````8````*@%```\I/__
MYP````!!#@B&`D$.#(,#3@X@5@XL00XP3`X@9@XL00XP2`X@0PH.#$'##@A!
MQ@X$20M>#BQ!#C!(#B!J#B1!#BA!#BQ'#C!(#B!%"@X,0<,."$'&#@1'"S0`
M```,!@``R*3__\0!````00X(AP)!#@R&`T$.$(,$3@Y``V`!"@X00<,.#$'&
M#@A!QPX$1`L`(````$0&``!@IO__=@````!!#@B#`DX.(&<*#@A!PPX$20L`
M*````&@&``"\IO__-`````!!#@B#`DX.$$@.'$$.($@.$$D*#@A!PPX$1@MH
M````E`8``-"F___'`````$$."(4"00X,AP-!#A"&!$$.%(,%3@XP;0XX00X\
M00Y`2`XP1PX\00Y`9@XT00XX00X\1PY`00Y$0@Y(0@Y,00Y03@XP:0H.%$'#
M#A!!Q@X,0<<."$'%#@1!"P#(`P````<``#2G__^Q#````$$."(4"00X,AP-!
M#A"&!$$.%(,%40[0@@("P@[<@@)!#N""`E@.T(("5P[<@@)$#N""`D$.Y(("
M0@[H@@)"#NR"`D$.\(("2P[0@@)_#MR"`D$.X(("2`[0@@("?0[<@@)*#N""
M`E(.Y(("00[H@@)+#NR"`D<.\(("0P[T@@)"#OB"`D(._(("00Z`@P)(#MB"
M`D4.W(("00[@@@)(#M""`EX.W(("0@[@@@)(#M2"`D8.V(("1`[<@@)"#N""
M`D@.T(("30[<@@)$#N""`D8.Y(("1P[H@@)(#NR"`D(.\(("2`[0@@)T#MR"
M`D$.X(("2`[0@@)<#MR"`D$.X(("7`[0@@)>"@X40<,.$$'&#@Q!QPX(0<4.
M!$8+:`[<@@)(#N""`DP.T(("3P[<@@)!#N""`D@.T(("5P[<@@)"#N""`DX.
MT(("4P[<@@)"#N""`E<.T(("30[<@@)"#N""`DX.T(("4P[<@@)!#N""`EL.
MT(("2P[<@@)!#N""`D8.W(("00[8@@)!#MR"`D8.X(("3`[0@@)+#MR"`D4.
MX(("2`[0@@("0P[8@@)"#MR"`D0.X(("3`[0@@)K#M2"`D$.V(("2@[<@@)$
M#N""`D$.Y(("0@[H@@)"#NR"`D0.\(("2`[0@@)D#MR"`D0.X(("00[D@@)!
M#NB"`D0.[(("1`[P@@)!#O2"`D(.^(("0@[\@@)!#H"#`D@.T(("0P[8@@)%
M#MR"`D$.X(("2`[0@@)(#MR"`D0.X(("80[0@@);#M2"`D(.V(("0@[<@@)%
M#N""`D@.U(("0@[8@@),#MR"`D$.X(("2`[0@@):#M2"`D(.V(("0@[<@@)$
M#N""`@*M#M""`EH.U(("10[8@@)$#MR"`D0.X(("2`[0@@("F@[4@@)!#MB"
M`D0.W(("0P[@@@)8#M""`@,1`0[4@@)!#MB"`D$.W(("1`[@@@)/#M""`EL.
MW(("1`[@@@("1@[0@@(#Y`$.W(("00[@@@)!#N2"`D(.Z(("0@[L@@)!#O""
M`DL.T(("50[4@@)*#MB"`D0.W(("1`[@@@)!#N2"`D(.Z(("0@[L@@)$#O""
M`D@.T(("5P[<@@)!#N""`DP.T(("`F8*#MB"`D$.W(("1`[@@@)&#N2"`DL+
M`G(.U(("0@[8@@)"#MR"`D4.X(("2`[4@@)"#MB"`D4.W(("00[@@@),#N2"
M`D<.Z(("1`[L@@)$#O""`D$.](("0@[X@@)"#OR"`D0.@(,"2`[0@@(```!P
M`0``S`H``"BP__^&`P```$$."(4"00X,AP-!#A"&!$$.%(,%3@Y,5`Y01@Y,
M0@Y09@Y`50Y,0@Y030Y40@Y800Y<00Y@2`Y`<@Y(1`Y,20Y03`Y`6@Y,00Y0
M1PY400Y81`Y<00Y@2`Y`7@Y,00Y01PY40@Y810Y<00Y@2@Y`=@Y,1`Y01@Y,
M00Y(00Y,00Y02`Y`30Y,00Y030Y40@Y800Y<00Y@2`Y`3`Y,1`Y03@Y$00Y(
M00Y,00Y02PY`3PY,0@Y030Y40@Y800Y<00Y@2`Y`90Y,1`Y02`Y$00Y(00Y,
M00Y02`Y`0PY,0@Y03@Y$0@Y(00Y,00Y02`Y,0@Y03@Y$00Y(00Y,00Y01@Y,
M0@Y06PY`3PY(10Y,00Y02PY`8@H.%$'##A!!Q@X,0<<."$'%#@1*"T,*#DQ&
M#E!(#D!5#DQ!#E!)"UD.3$D.4%$.0%`.3$(.4$8.3$$.2$$.3$$.4$@.0$L.
M1$<.2$(.3$<.4`!$````0`P``$2R__]O`````$$."(<"00X,A@-!#A"#!%(.
M'$$.($L.$`)!"L,.#$'&#@A!QPX$00M#PPX,0<8."$''#@0```!$````B`P`
M`(QG__\\`@```$0,`0!'$`4"=0!&#P-U<`80!P)U?!`&`G5X$`,"=70#=P$*
MP0P!`$'#0<9!QT'%0PP$!$$+```0````T`P``".R__\$`````````"@```#D
M#```(++__RL`````00X(@P).#A!&#A1$#AA$#AQ$#B!(#@A!PPX$2````!`-
M```DLO__70````!!#@B%`D$.#(<#00X0A@1!#A2#!4X.(&D.)$$.*$0.+$0.
M,$T.($<.%$'##A!!Q@X,0<<."$'%#@0``!````!<#0``.++__P(`````````
M&````'`-```TLO__%`````!!#@B#`DX.$```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````,!D`
M`.`8```!`````0````$```#+`0```0```-8!```!````X`$```$````O`@``
M`0```(H#```,````O!$```T```!D80``&0```*C-```;````!````!H```"L
MS0``'`````0```#U_O]OK`$```4```#L"```!@```(P"```*````_`0```L`
M```0````%0`````````#````T,X```(```#@`0``%````!$````7````W`\`
M`!$```!4#P``$@```(@````3````"````!X````(````^___;P$```C^__]O
MM`X``/___V\"````\/__;^@-``#Z__]O!0``````````````````````````
M``````````````````````````````"PS0````````````#V$0``!A(``!82
M```F$@``-A(``$82``!6$@``9A(``'82``"&$@``EA(``*82``"V$@``QA(`
M`-82``#F$@``]A(```83```6$P``)A,``#83``!&$P``5A,``&83``!V$P``
MAA,``)83``"F$P``MA,``,83``#6$P``YA,``/83```&%```%A0``"84```V
M%```1A0``%84``!F%```=A0``(84``"6%```IA0``+84``#&%```UA0``.84
M``#V%```!A4``!85```F%0``-A4``$85``!6%0``9A4``'85``"&%0``EA4`
M`*85````````````````````````````````````````````````````````
M``````````#`%0````````30``#_____@&0``$=#0SH@*$1E8FEA;B`W+C,N
M,"TQ-BD@-RXS+C``1T-#.B`H1&5B:6%N(#<N,RXP+3$S*2`W+C,N,```+G-H
M<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T92YG;G4N8G5I;&0M
M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N
M=2YV97)S:6]N7W(`+G)E;"YD>6X`+G)E;"YP;'0`+FEN:70`+G!L="YG;W0`
M+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N
M:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9&%T80`N8G-S`"YC
M;VUM96YT````````````````````````````````````````````````````
M``````L````!`````@```%0!``!4`0``$P```````````````0`````````3
M````!P````(```!H`0``:`$``"````````````````0`````````(0````<`
M```"````B`$``(@!```D```````````````$`````````#0```#V__]O`@``
M`*P!``"L`0``X`````4`````````!`````0````^````"P````(```",`@``
MC`(``&`&```&`````0````0````0````1@````,````"````[`@``.P(``#\
M!``````````````!`````````$X```#___]O`@```.@-``#H#0``S`````4`
M`````````@````(```!;````_O__;P(```"T#@``M`X``*`````&`````@``
M``0`````````:@````D````"````5`\``%0/``"(````!0`````````$````
M"````',````)````0@```-P/``#<#P``X`$```4````6````!`````@```!\
M`````0````8```"\$0``O!$``",```````````````0`````````=P````$`
M```&````X!$``.`1``#0`P`````````````0````!````((````!````!@``
M`+`5``"P%0``$```````````````"`````@```"+`````0````8```#`%0``
MP!4``*1+`````````````!``````````D0````$````&````9&$``&1A```4
M```````````````$`````````)<````!`````@```'AA``!X80``/#\`````
M````````!`````````"?`````0````(```"TH```M*```/0`````````````
M``0`````````K0````$````"````J*$``*BA``",#0`````````````$````
M`````+<````.`````P```*C-``"HO0``!```````````````!`````0```##
M````#P````,```"LS0``K+T```0```````````````0````$````SP````8`
M```#````L,T``+"]```@`0``!@`````````$````"````(8````!`````P``
M`-#.``#0O@``,`$`````````````!`````0```#8`````0````,`````T```
M`,```!````````````````0`````````W@````@````#````(-```!#````T
M$``````````````@`````````.,````!````,``````````0P```.@``````
M`````````0````$````!`````P``````````````2L```.P`````````````
)``$`````````
